from files import get_csv_contents
import numpy as np
import datetime as dt
from glob import glob
import numpy.ma as ma
import iris

def read_atom_nav_file(file_path, flight_number):
    filename = file_path + "ATom{}_flight_tracks.csv".format(flight_number)
    file_contents, n_rows, n_cols = get_csv_contents(filename)

    # use datetime to convert date string
    # and add on number of seconds for start and end of interval
    fmt = '%Y%m%d'
    ts_date = np.array([dt.datetime.strptime(T, fmt) for T in file_contents[14:,2]])
    ts_start = np.array([ts_date[t] + dt.timedelta(seconds=float(T)) for t,T in enumerate(file_contents[14:,3])])
    ts_end = np.array([ts_date[t] + dt.timedelta(seconds=float(T)) for t,T in enumerate(file_contents[14:,4])])

    lat = np.array(file_contents[14:,5].astype(float))
    lon = np.array(file_contents[14:,6].astype(float))
    alt = np.array(file_contents[14:,7].astype(float))
    P = np.array(file_contents[14:,8])
    T = np.array(file_contents[14:,9])
    
    return ts_start, ts_end, lat, lon, alt, P, T

def get_ascos_track(ascos_dir):
    ascos_files = glob(ascos_dir+'*')
    ascos_lons = []
    ascos_lats = []
    for file in ascos_files:
        file_contents, nrows, ncols = get_csv_contents(file)
        lats = np.array(file_contents[2:,1]).astype(float)
        lons = np.array(file_contents[2:,2]).astype(float)
        west_east = np.array(file_contents[2:,3]).astype(float)
        for i,lon in enumerate(lons):
            if west_east[i] == 0.:
                lons[i] = -lon
        lats = ma.masked_values(lats, -99999.)
        lons = ma.masked_values(lons, -99999.)
        ascos_lats.append(lats)
        ascos_lons.append(lons)
    return ascos_lons, ascos_lats

def get_ao2018_track():
    '''
    Defines and returns a structured array of lat/lon position of Oden during MOCCHA
    along with timestamps of when each coordinate was recorded.
    '''
    dtypes = [('year',int),('month',int),('day',int),('hours',int),
             ('mins',int),('secs',int),('lon',float),('lat',float)]

    ship_coords_array = np.array([
                                (2018,8,1,0,0,0,15.62630492,78.23114692),
                                (2018,8,1,1,0,0,15.62749100,78.23121367),
                                (2018,8,1,2,0,0,15.62694142,78.23131400),
                                (2018,8,1,3,0,0,15.62979058,78.23138500),
                                (2018,8,1,4,0,0,15.62982050,78.23138100),
                                (2018,8,1,5,0,0,15.62933892,78.23112425),
                                (2018,8,1,6,0,0,15.63030725,78.23145817),
                                (2018,8,1,7,0,0,15.63009083,78.23132317),
                                (2018,8,1,8,0,0,15.62960233,78.23122108),
                                (2018,8,1,9,0,0,15.63054617,78.23123250),
                                (2018,8,1,10,0,0,15.63057058,78.23129008),
                                (2018,8,1,11,0,0,15.62989758,78.23120850),
                                (2018,8,1,12,0,0,15.62874625,78.23105000),
                                (2018,8,1,13,0,0,15.29273433,78.26595458),
                                (2018,8,1,14,0,0,14.50134358,78.19834608),
                                (2018,8,1,15,0,0,13.70967533,78.13038400),
                                (2018,8,1,16,0,0,12.97877417,78.04059517),
                                (2018,8,1,17,0,0,12.20095425,77.98001117),
                                (2018,8,1,18,0,0,11.40222167,78.00276425),
                                (2018,8,1,19,0,0,10.75888825,78.12119717),
                                (2018,8,1,20,0,0,10.12855608,78.24252433),
                                (2018,8,1,21,0,0,9.48837558,78.37758583),
                                (2018,8,1,22,0,0,8.85048467,78.51086000),
                                (2018,8,1,23,0,0,8.33558627,78.65118555),
                                (2018,8,2,0,0,0,8.28865400,78.83256883),
                                (2018,8,2,1,0,0,8.24109650,79.01353633),
                                (2018,8,2,2,0,0,8.19311900,79.19355725),
                                (2018,8,2,3,0,0,8.14322825,79.37822575),
                                (2018,8,2,4,0,0,8.09234817,79.56088100),
                                (2018,8,2,5,0,0,8.04085992,79.74289533),
                                (2018,8,2,6,0,0,8.05134083,79.92456392),
                                (2018,8,2,7,0,0,8.19687200,80.09671983),
                                (2018,8,2,8,0,0,8.34507625,80.26863533),
                                (2018,8,2,9,0,0,8.49709650,80.44230317),
                                (2018,8,2,10,0,0,8.65565975,80.61978508),
                                (2018,8,2,11,0,0,8.81349958,80.79331983),
                                (2018,8,2,12,0,0,9.08890625,80.96425033),
                                (2018,8,2,13,0,0,9.23776458,81.13776850),
                                (2018,8,2,14,0,0,9.29797058,81.31985642),
                                (2018,8,2,15,0,0,9.42626408,81.50155725),
                                (2018,8,2,16,0,0,9.60405008,81.68079550),
                                (2018,8,2,17,0,0,9.83512250,81.85878200),
                                (2018,8,2,18,0,0,9.99981342,82.03839717),
                                (2018,8,2,19,0,0,9.97389817,82.15382250),
                                (2018,8,2,20,0,0,9.90398292,82.17389008),
                                (2018,8,2,21,0,0,9.86186333,82.19312492),
                                (2018,8,2,22,0,0,10.02745667,82.20628075),
                                (2018,8,2,23,0,0,10.35264482,82.20669055),
                                (2018,8,3,0,0,0,10.62781942,82.20224225),
                                (2018,8,3,1,0,0,10.83136075,82.20045142),
                                (2018,8,3,2,0,0,11.03505217,82.20326933),
                                (2018,8,3,3,0,0,11.25059817,82.20768033),
                                (2018,8,3,4,0,0,11.45063317,82.21292325),
                                (2018,8,3,5,0,0,11.63128042,82.22088700),
                                (2018,8,3,6,0,0,11.80352258,82.20773083),
                                (2018,8,3,7,0,0,11.91995000,82.20226692),
                                (2018,8,3,8,0,0,12.02995450,82.18857825),
                                (2018,8,3,9,0,0,12.11149892,82.17197275),
                                (2018,8,3,10,0,0,12.17569217,82.15300925),
                                (2018,8,3,11,0,0,12.17502325,82.13615167),
                                (2018,8,3,12,0,0,12.13615033,82.11553458),
                                (2018,8,3,13,0,0,12.10478008,82.09237575),
                                (2018,8,3,14,0,0,12.08778208,82.07013700),
                                (2018,8,3,15,0,0,12.06424300,82.05238692),
                                (2018,8,3,16,0,0,12.02016400,82.05170775),
                                (2018,8,3,17,0,0,11.98596008,82.05385425),
                                (2018,8,3,18,0,0,11.96849308,82.05721983),
                                (2018,8,3,19,0,0,11.96779683,82.06183375),
                                (2018,8,3,20,0,0,11.98271258,82.06541417),
                                (2018,8,3,21,0,0,12.00671450,82.06693567),
                                (2018,8,3,22,0,0,12.02972742,82.06630725),
                                (2018,8,3,23,0,0,12.36595473,82.13123200),
                                (2018,8,4,0,0,0,12.85597083,82.22665167),
                                (2018,8,4,1,0,0,13.20327267,82.29798592),
                                (2018,8,4,2,0,0,13.55738483,82.37429308),
                                (2018,8,4,3,0,0,13.95534258,82.46290567),
                                (2018,8,4,4,0,0,14.42261367,82.55555875),
                                (2018,8,4,5,0,0,14.88857825,82.64385683),
                                (2018,8,4,6,0,0,15.33784217,82.73128817),
                                (2018,8,4,7,0,0,15.82145283,82.81925642),
                                (2018,8,4,8,0,0,16.37334800,82.89872725),
                                (2018,8,4,9,0,0,16.81887775,82.98358267),
                                (2018,8,4,10,0,0,17.20125608,83.06707433),
                                (2018,8,4,11,0,0,17.69286525,83.13410825),
                                (2018,8,4,12,0,0,18.06346208,83.21356542),
                                (2018,8,4,13,0,0,18.36865633,83.25687225),
                                (2018,8,4,14,0,0,18.86164500,83.33245617),
                                (2018,8,4,15,0,0,19.32424000,83.40414917),
                                (2018,8,4,16,0,0,19.73266250,83.47102175),
                                (2018,8,4,17,0,0,20.09211675,83.53821092),
                                (2018,8,4,18,0,0,20.49291217,83.61466700),
                                (2018,8,4,19,0,0,20.93179025,83.67528225),
                                (2018,8,4,20,0,0,21.49091217,83.71663567),
                                (2018,8,4,21,0,0,22.53637392,83.76684942),
                                (2018,8,4,22,0,0,22.73198717,83.73975283),
                                (2018,8,4,23,0,0,22.94584827,83.74147755),
                                (2018,8,5,0,0,0,23.67940333,83.72787875),
                                (2018,8,5,1,0,0,24.41837383,83.75424283),
                                (2018,8,5,2,0,0,25.19824975,83.82175267),
                                (2018,8,5,3,0,0,25.73273233,83.89254858),
                                (2018,8,5,4,0,0,26.13876267,83.96511717),
                                (2018,8,5,5,0,0,26.40151192,84.01455617),
                                (2018,8,5,6,0,0,26.69415867,84.08981833),
                                (2018,8,5,7,0,0,27.04369683,84.17021217),
                                (2018,8,5,8,0,0,27.29124950,84.24444825),
                                (2018,8,5,9,0,0,27.72296767,84.29112183),
                                (2018,8,5,10,0,0,28.13216475,84.37882367),
                                (2018,8,5,11,0,0,28.63167417,84.45963300),
                                (2018,8,5,12,0,0,29.13151992,84.50660292),
                                (2018,8,5,13,0,0,29.69949000,84.55786600),
                                (2018,8,5,14,0,0,30.16153067,84.61622825),
                                (2018,8,5,15,0,0,30.49962742,84.68841358),
                                (2018,8,5,16,0,0,31.00764992,84.75819700),
                                (2018,8,5,17,0,0,31.28918883,84.83052892),
                                (2018,8,5,18,0,0,31.39672100,84.89131750),
                                (2018,8,5,19,0,0,31.54286425,84.96788050),
                                (2018,8,5,20,0,0,31.18045800,85.01845358),
                                (2018,8,5,21,0,0,31.03310300,85.06063108),
                                (2018,8,5,22,0,0,30.99253625,85.10241617),
                                (2018,8,5,23,0,0,30.97492264,85.16782836),
                                (2018,8,6,0,0,0,30.84231875,85.20734083),
                                (2018,8,6,1,0,0,30.89217942,85.24761100),
                                (2018,8,6,2,0,0,30.60710700,85.29857775),
                                (2018,8,6,3,0,0,30.76034242,85.35657275),
                                (2018,8,6,4,0,0,30.75632958,85.40410675),
                                (2018,8,6,5,0,0,30.97208242,85.44939467),
                                (2018,8,6,6,0,0,31.16041492,85.48542767),
                                (2018,8,6,7,0,0,31.20799992,85.53179058),
                                (2018,8,6,8,0,0,31.45174392,85.58561300),
                                (2018,8,6,9,0,0,31.41737467,85.63377483),
                                (2018,8,6,10,0,0,31.38994283,85.68349158),
                                (2018,8,6,11,0,0,31.38065267,85.71750858),
                                (2018,8,6,12,0,0,31.43989758,85.74970475),
                                (2018,8,6,13,0,0,31.39239433,85.78255517),
                                (2018,8,6,14,0,0,31.47195475,85.81783450),
                                (2018,8,6,15,0,0,31.30925883,85.86269925),
                                (2018,8,6,16,0,0,31.46147300,85.88637542),
                                (2018,8,6,17,0,0,31.64263742,85.94848150),
                                (2018,8,6,18,0,0,31.93118825,85.97200775),
                                (2018,8,6,19,0,0,31.85488383,86.01666525),
                                (2018,8,6,20,0,0,32.35029117,86.05652083),
                                (2018,8,6,21,0,0,32.91996192,86.09294633),
                                (2018,8,6,22,0,0,33.41500658,86.06996300),
                                (2018,8,6,23,0,0,33.99543591,86.08267845),
                                (2018,8,7,0,0,0,34.13378075,86.11240192),
                                (2018,8,7,1,0,0,34.03912208,86.12573933),
                                (2018,8,7,2,0,0,34.55204025,86.13859458),
                                (2018,8,7,3,0,0,35.03959567,86.14456167),
                                (2018,8,7,4,0,0,35.00612808,86.17867833),
                                (2018,8,7,5,0,0,34.96699950,86.20466417),
                                (2018,8,7,6,0,0,34.67787475,86.23791708),
                                (2018,8,7,7,0,0,34.39413958,86.30059967),
                                (2018,8,7,8,0,0,33.66228233,86.35721842),
                                (2018,8,7,9,0,0,33.60490142,86.39015833),
                                (2018,8,7,10,0,0,33.57841667,86.45894767),
                                (2018,8,7,11,0,0,33.58642258,86.50914617),
                                (2018,8,7,12,0,0,33.98190525,86.53781225),
                                (2018,8,7,13,0,0,33.76192375,86.59453633),
                                (2018,8,7,14,0,0,34.01798767,86.64346008),
                                (2018,8,7,15,0,0,33.70253942,86.66879333),
                                (2018,8,7,16,0,0,33.64677283,86.72025875),
                                (2018,8,7,17,0,0,34.07399042,86.72414450),
                                (2018,8,7,18,0,0,34.49456892,86.73632783),
                                (2018,8,7,19,0,0,34.61244308,86.75268342),
                                (2018,8,7,20,0,0,34.91242458,86.76749108),
                                (2018,8,7,21,0,0,35.34589408,86.79956883),
                                (2018,8,7,22,0,0,35.63965333,86.80673417),
                                (2018,8,7,23,0,0,35.38183309,86.79964682),
                                (2018,8,8,0,0,0,35.94725450,86.76485367),
                                (2018,8,8,1,0,0,37.04025142,86.74642533),
                                (2018,8,8,2,0,0,37.60771658,86.77240642),
                                (2018,8,8,3,0,0,38.32365300,86.81398283),
                                (2018,8,8,4,0,0,38.65480017,86.84094433),
                                (2018,8,8,5,0,0,39.01027725,86.88081417),
                                (2018,8,8,6,0,0,39.01803133,86.92691692),
                                (2018,8,8,7,0,0,39.19791567,86.97068517),
                                (2018,8,8,8,0,0,39.42998475,87.01719017),
                                (2018,8,8,9,0,0,39.79550783,87.05412833),
                                (2018,8,8,10,0,0,40.14744325,87.11909292),
                                (2018,8,8,11,0,0,40.60342267,87.16180750),
                                (2018,8,8,12,0,0,41.79301708,87.17338825),
                                (2018,8,8,13,0,0,42.71814525,87.19509225),
                                (2018,8,8,14,0,0,43.94606800,87.19951858),
                                (2018,8,8,15,0,0,44.39298983,87.25684617),
                                (2018,8,8,16,0,0,45.22861733,87.29075633),
                                (2018,8,8,17,0,0,45.80624592,87.33713733),
                                (2018,8,8,18,0,0,45.21550133,87.36161833),
                                (2018,8,8,19,0,0,45.41600200,87.41505867),
                                (2018,8,8,20,0,0,45.10990617,87.45821083),
                                (2018,8,8,21,0,0,45.09251725,87.50342967),
                                (2018,8,8,22,0,0,45.21734950,87.54444558),
                                (2018,8,8,23,0,0,44.97491518,87.59387573),
                                (2018,8,9,0,0,0,45.24840700,87.64681717),
                                (2018,8,9,1,0,0,45.44521067,87.69367900),
                                (2018,8,9,2,0,0,45.68887217,87.73201992),
                                (2018,8,9,3,0,0,45.95163358,87.76485467),
                                (2018,8,9,4,0,0,46.08314767,87.81297542),
                                (2018,8,9,5,0,0,46.84388142,87.86149125),
                                (2018,8,9,6,0,0,47.19966075,87.90468192),
                                (2018,8,9,7,0,0,47.48724758,87.95675775),
                                (2018,8,9,8,0,0,47.11105683,88.01505800),
                                (2018,8,9,9,0,0,46.95438925,88.02935767),
                                (2018,8,9,10,0,0,46.38955858,88.08895183),
                                (2018,8,9,11,0,0,46.10068433,88.13147300),
                                (2018,8,9,12,0,0,45.72065800,88.17067125),
                                (2018,8,9,13,0,0,45.96179425,88.21602067),
                                (2018,8,9,14,0,0,45.96067200,88.26467358),
                                (2018,8,9,15,0,0,45.42523817,88.32447233),
                                (2018,8,9,16,0,0,44.92481483,88.37246600),
                                (2018,8,9,17,0,0,44.29544425,88.41979442),
                                (2018,8,9,18,0,0,44.88978800,88.44757542),
                                (2018,8,9,19,0,0,45.19203042,88.47041017),
                                (2018,8,9,20,0,0,45.24855300,88.50720108),
                                (2018,8,9,21,0,0,45.29692433,88.54393667),
                                (2018,8,9,22,0,0,46.22206017,88.54902575),
                                (2018,8,9,23,0,0,45.87472564,88.56725536),
                                (2018,8,10,0,0,0,46.76985458,88.55605675),
                                (2018,8,10,1,0,0,47.99421425,88.56196167),
                                (2018,8,10,2,0,0,49.48517750,88.56450942),
                                (2018,8,10,3,0,0,49.50863483,88.60396883),
                                (2018,8,10,4,0,0,49.98715567,88.64880142),
                                (2018,8,10,5,0,0,50.15303258,88.67650342),
                                (2018,8,10,6,0,0,50.25446700,88.69939042),
                                (2018,8,10,7,0,0,50.65041067,88.75019692),
                                (2018,8,10,8,0,0,50.80016642,88.78616558),
                                (2018,8,10,9,0,0,51.64781608,88.81937242),
                                (2018,8,10,10,0,0,51.71583058,88.86467017),
                                (2018,8,10,11,0,0,51.96074208,88.88512325),
                                (2018,8,10,12,0,0,51.98530308,88.88687183),
                                (2018,8,10,13,0,0,52.00779975,88.88843542),
                                (2018,8,10,14,0,0,52.02616942,88.88986050),
                                (2018,8,10,15,0,0,52.04012250,88.89123083),
                                (2018,8,10,16,0,0,51.88777483,88.89302217),
                                (2018,8,10,17,0,0,51.89617108,88.89439108),
                                (2018,8,10,18,0,0,51.90788950,88.89575717),
                                (2018,8,10,19,0,0,51.92653558,88.89712933),
                                (2018,8,10,20,0,0,51.95282667,88.89843500),
                                (2018,8,10,21,0,0,51.98980842,88.89966758),
                                (2018,8,10,22,0,0,52.03696125,88.90080525),
                                (2018,8,10,23,0,0,52.09506427,88.90181491),
                                (2018,8,11,0,0,0,52.16436767,88.90264167),
                                (2018,8,11,1,0,0,52.19076217,88.91161567),
                                (2018,8,11,2,0,0,51.20959375,88.96453058),
                                (2018,8,11,3,0,0,50.62699492,89.00686117),
                                (2018,8,11,4,0,0,51.32669017,89.04869142),
                                (2018,8,11,5,0,0,51.15561650,89.09437817),
                                (2018,8,11,6,0,0,50.60662217,89.15179342),
                                (2018,8,11,7,0,0,52.46763500,89.17395500),
                                (2018,8,11,8,0,0,54.92887850,89.22329308),
                                (2018,8,11,9,0,0,58.48935542,89.24889317),
                                (2018,8,11,10,0,0,61.93233608,89.25444842),
                                (2018,8,11,11,0,0,64.05527792,89.26530117),
                                (2018,8,11,12,0,0,64.18056383,89.31878983),
                                (2018,8,11,13,0,0,63.65590417,89.37657000),
                                (2018,8,11,14,0,0,62.69612692,89.43446150),
                                (2018,8,11,15,0,0,59.85345875,89.50392500),
                                (2018,8,11,16,0,0,55.99678750,89.55974758),
                                (2018,8,11,17,0,0,48.83381392,89.60879950),
                                (2018,8,11,18,0,0,44.56089867,89.64614267),
                                (2018,8,11,19,0,0,34.92631692,89.70010075),
                                (2018,8,11,20,0,0,27.69254042,89.72888725),
                                (2018,8,11,21,0,0,31.25500233,89.77404242),
                                (2018,8,11,22,0,0,39.51319833,89.76276467),
                                (2018,8,11,23,0,0,42.36466518,89.80819309),
                                (2018,8,12,0,0,0,43.74398792,89.85146900),
                                (2018,8,12,1,0,0,40.11172283,89.89017917),
                                (2018,8,12,2,0,0,38.93589900,89.90222575),
                                (2018,8,12,3,0,0,39.77955917,89.89258725),
                                (2018,8,12,4,0,0,39.42471800,89.89269717),
                                (2018,8,12,5,0,0,39.06443883,89.89288525),
                                (2018,8,12,6,0,0,38.72651075,89.89310383),
                                (2018,8,12,7,0,0,38.43336925,89.89325533),
                                (2018,8,12,8,0,0,38.09835142,89.89329367),
                                (2018,8,12,9,0,0,37.84861033,89.89317600),
                                (2018,8,12,10,0,0,37.73788417,89.89267767),
                                (2018,8,12,11,0,0,37.66505158,89.89190167),
                                (2018,8,12,12,0,0,37.49861292,89.89101458),
                                (2018,8,12,13,0,0,37.20716708,89.89023083),
                                (2018,8,12,14,0,0,36.73154867,89.88964992),
                                (2018,8,12,15,0,0,35.94499092,89.88939475),
                                (2018,8,12,16,0,0,35.12712500,89.88947825),
                                (2018,8,12,17,0,0,34.32674325,89.88972683),
                                (2018,8,12,18,0,0,33.55771817,89.88931958),
                                (2018,8,12,19,0,0,36.04685567,89.86149908),
                                (2018,8,12,20,0,0,38.17672858,89.82387208),
                                (2018,8,12,21,0,0,36.17216700,89.76434167),
                                (2018,8,12,22,0,0,23.45409550,89.76367575),
                                (2018,8,12,23,0,0,24.94874982,89.71738409),
                                (2018,8,13,0,0,0,30.81813158,89.69216467),
                                (2018,8,13,1,0,0,35.09985667,89.67807933),
                                (2018,8,13,2,0,0,36.79034108,89.66938842),
                                (2018,8,13,3,0,0,38.63610558,89.65980500),
                                (2018,8,13,4,0,0,41.10331367,89.63296800),
                                (2018,8,13,5,0,0,42.45853242,89.62516225),
                                (2018,8,13,6,0,0,40.60617058,89.60603842),
                                (2018,8,13,7,0,0,40.49162658,89.60649217),
                                (2018,8,13,8,0,0,40.39580150,89.60670042),
                                (2018,8,13,9,0,0,40.30481142,89.60664467),
                                (2018,8,13,10,0,0,40.19096358,89.60634675),
                                (2018,8,13,11,0,0,40.04384325,89.60574550),
                                (2018,8,13,12,0,0,39.93678908,89.60477600),
                                (2018,8,13,13,0,0,39.83895358,89.60358183),
                                (2018,8,13,14,0,0,39.67603225,89.60241100),
                                (2018,8,13,15,0,0,39.44620425,89.60136750),
                                (2018,8,13,16,0,0,39.21047100,89.60050650),
                                (2018,8,13,17,0,0,38.99945592,89.59968825),
                                (2018,8,13,18,0,0,41.03934942,89.61593100),
                                (2018,8,13,19,0,0,41.05357850,89.61766342),
                                (2018,8,13,20,0,0,40.81193892,89.61632500),
                                (2018,8,13,21,0,0,40.58744300,89.61476250),
                                (2018,8,13,22,0,0,40.37569742,89.61293908),
                                (2018,8,13,23,0,0,40.10008373,89.61069936),
                                (2018,8,14,0,0,0,39.84374167,89.60816625),
                                (2018,8,14,1,0,0,39.61092367,89.60555100),
                                (2018,8,14,2,0,0,39.35860117,89.60302317),
                                (2018,8,14,3,0,0,39.14381683,89.60057325),
                                (2018,8,14,4,0,0,38.84844317,89.59832750),
                                (2018,8,14,5,0,0,38.58664742,89.59632450),
                                (2018,8,14,6,0,0,38.32815458,89.59474600),
                                (2018,8,14,7,0,0,38.10107625,89.59329275),
                                (2018,8,14,8,0,0,37.92191842,89.59137792),
                                (2018,8,14,9,0,0,37.75776067,89.58938250),
                                (2018,8,14,10,0,0,37.64221183,89.58723942),
                                (2018,8,14,11,0,0,37.41863133,89.58471808),
                                (2018,8,14,12,0,0,37.23201817,89.58203792),
                                (2018,8,14,13,0,0,37.08044083,89.57943725),
                                (2018,8,14,14,0,0,36.91983392,89.57691675),
                                (2018,8,14,15,0,0,36.73035117,89.57453233),
                                (2018,8,14,16,0,0,36.54376842,89.57233850),
                                (2018,8,14,17,0,0,36.34173625,89.57021442),
                                (2018,8,14,18,0,0,36.13855508,89.56814858),
                                (2018,8,14,19,0,0,35.96049400,89.56613933),
                                (2018,8,14,20,0,0,35.83850592,89.56399058),
                                (2018,8,14,21,0,0,35.74193600,89.56150567),
                                (2018,8,14,22,0,0,35.61596642,89.55870608),
                                (2018,8,14,23,0,0,35.50856918,89.55553955),
                                (2018,8,15,0,0,0,35.41359067,89.55215608),
                                (2018,8,15,1,0,0,35.32992800,89.54854258),
                                (2018,8,15,2,0,0,35.24740300,89.54464825),
                                (2018,8,15,3,0,0,35.14351575,89.54014842),
                                (2018,8,15,4,0,0,35.06089742,89.53543883),
                                (2018,8,15,5,0,0,34.96760750,89.53060450),
                                (2018,8,15,6,0,0,34.87662783,89.52540350),
                                (2018,8,15,7,0,0,34.79183692,89.52026267),
                                (2018,8,15,8,0,0,34.69316975,89.51523142),
                                (2018,8,15,9,0,0,34.58766717,89.51036317),
                                (2018,8,15,10,0,0,34.35292350,89.50362142),
                                (2018,8,15,11,0,0,34.26231817,89.49959400),
                                (2018,8,15,12,0,0,34.14560925,89.49519517),
                                (2018,8,15,13,0,0,34.03266483,89.49088717),
                                (2018,8,15,14,0,0,33.92615792,89.48675725),
                                (2018,8,15,15,0,0,33.81761517,89.48282175),
                                (2018,8,15,16,0,0,33.70658033,89.47920442),
                                (2018,8,15,17,0,0,33.58728442,89.47596858),
                                (2018,8,15,18,0,0,33.46564483,89.47309125),
                                (2018,8,15,19,0,0,33.34426967,89.47058408),
                                (2018,8,15,20,0,0,33.22532800,89.46835717),
                                (2018,8,15,21,0,0,33.10495533,89.46622917),
                                (2018,8,15,22,0,0,32.98103208,89.46410658),
                                (2018,8,15,23,0,0,32.85199500,89.46170536),
                                (2018,8,16,0,0,0,32.71614592,89.45919567),
                                (2018,8,16,1,0,0,32.56787617,89.45668467),
                                (2018,8,16,2,0,0,32.40883617,89.45436783),
                                (2018,8,16,3,0,0,32.24223717,89.45240250),
                                (2018,8,16,4,0,0,32.06420608,89.45086583),
                                (2018,8,16,5,0,0,31.88291442,89.44979242),
                                (2018,8,16,6,0,0,31.69963575,89.44914175),
                                (2018,8,16,7,0,0,31.52903033,89.44881925),
                                (2018,8,16,8,0,0,31.38378442,89.44868367),
                                (2018,8,16,9,0,0,31.26036108,89.44857058),
                                (2018,8,16,10,0,0,31.15106408,89.44839050),
                                (2018,8,16,11,0,0,31.04823133,89.44810475),
                                (2018,8,16,12,0,0,30.88798758,89.44972625),
                                (2018,8,16,13,0,0,30.82564825,89.44734917),
                                (2018,8,16,14,0,0,30.69314542,89.44731458),
                                (2018,8,16,15,0,0,30.54459567,89.44766675),
                                (2018,8,16,16,0,0,30.39173875,89.44854517),
                                (2018,8,16,17,0,0,30.24326142,89.44997583),
                                (2018,8,16,18,0,0,30.10806100,89.45182800),
                                (2018,8,16,19,0,0,29.99036175,89.45404658),
                                (2018,8,16,20,0,0,29.89117700,89.45651175),
                                (2018,8,16,21,0,0,29.81301242,89.45907517),
                                (2018,8,16,22,0,0,29.75235083,89.46162842),
                                (2018,8,16,23,0,0,29.70414091,89.46411545),
                                (2018,8,17,0,0,0,29.66612692,89.46649250),
                                (2018,8,17,1,0,0,29.62358358,89.46876658),
                                (2018,8,17,2,0,0,29.58342142,89.47104233),
                                (2018,8,17,3,0,0,29.53435658,89.47338233),
                                (2018,8,17,4,0,0,29.48346100,89.47591583),
                                (2018,8,17,5,0,0,29.44189300,89.47872375),
                                (2018,8,17,6,0,0,29.42957808,89.48180200),
                                (2018,8,17,7,0,0,29.45569492,89.48506217),
                                (2018,8,17,8,0,0,29.52231900,89.48838133),
                                (2018,8,17,9,0,0,29.62683200,89.49161125),
                                (2018,8,17,10,0,0,29.76370283,89.49457917),
                                (2018,8,17,11,0,0,29.93339858,89.49715600),
                                (2018,8,17,12,0,0,30.13000275,89.49937783),
                                (2018,8,17,13,0,0,30.34062925,89.50128042),
                                (2018,8,17,14,0,0,30.54298025,89.50314992),
                                (2018,8,17,15,0,0,30.72794475,89.50513458),
                                (2018,8,17,16,0,0,30.91381042,89.50736100),
                                (2018,8,17,17,0,0,31.11761967,89.50989708),
                                (2018,8,17,18,0,0,31.34340808,89.51276600),
                                (2018,8,17,19,0,0,31.60532733,89.51587925),
                                (2018,8,17,20,0,0,31.91647833,89.51910933),
                                (2018,8,17,21,0,0,32.27125758,89.52219683),
                                (2018,8,17,22,0,0,32.64069000,89.52497492),
                                (2018,8,17,23,0,0,32.99666764,89.52750182),
                                (2018,8,18,0,0,0,33.32209883,89.52993892),
                                (2018,8,18,1,0,0,33.61749092,89.53261125),
                                (2018,8,18,2,0,0,33.91162275,89.53548542),
                                (2018,8,18,3,0,0,34.19265650,89.53863617),
                                (2018,8,18,4,0,0,34.47411092,89.54173517),
                                (2018,8,18,5,0,0,34.78980558,89.54449983),
                                (2018,8,18,6,0,0,35.06933083,89.54709308),
                                (2018,8,18,7,0,0,35.34708858,89.54926242),
                                (2018,8,18,8,0,0,35.65296067,89.55094242),
                                (2018,8,18,9,0,0,35.98279317,89.55239583),
                                (2018,8,18,10,0,0,36.33199033,89.55352875),
                                (2018,8,18,11,0,0,36.68875933,89.55454083),
                                (2018,8,18,12,0,0,37.04282792,89.55563408),
                                (2018,8,18,13,0,0,37.37773008,89.55656833),
                                (2018,8,18,14,0,0,37.68433783,89.55740500),
                                (2018,8,18,15,0,0,37.95693800,89.55819050),
                                (2018,8,18,16,0,0,38.20651950,89.55890608),
                                (2018,8,18,17,0,0,38.40846850,89.55984617),
                                (2018,8,18,18,0,0,38.59542883,89.56093175),
                                (2018,8,18,19,0,0,38.77817050,89.56210200),
                                (2018,8,18,20,0,0,38.97131025,89.56341483),
                                (2018,8,18,21,0,0,39.17901558,89.56463033),
                                (2018,8,18,22,0,0,39.38214958,89.56567217),
                                (2018,8,18,23,0,0,39.57577055,89.56669900),
                                (2018,8,19,0,0,0,39.75054117,89.56768217),
                                (2018,8,19,1,0,0,39.90841308,89.56871408),
                                (2018,8,19,2,0,0,40.04875375,89.56990283),
                                (2018,8,19,3,0,0,40.16214275,89.57107158),
                                (2018,8,19,4,0,0,40.22792150,89.57220225),
                                (2018,8,19,5,0,0,40.25084667,89.57337767),
                                (2018,8,19,6,0,0,40.21077892,89.57448883),
                                (2018,8,19,7,0,0,40.10222492,89.57570367),
                                (2018,8,19,8,0,0,39.99316133,89.57685942),
                                (2018,8,19,9,0,0,39.86872092,89.57797342),
                                (2018,8,19,10,0,0,39.72266133,89.58045708),
                                (2018,8,19,11,0,0,39.66809442,89.58181008),
                                (2018,8,19,12,0,0,39.46490875,89.58294025),
                                (2018,8,19,13,0,0,39.24116875,89.58406150),
                                (2018,8,19,14,0,0,38.99768725,89.58522117),
                                (2018,8,19,15,0,0,38.71825908,89.58655800),
                                (2018,8,19,16,0,0,38.44128650,89.58793767),
                                (2018,8,19,17,0,0,38.18327883,89.58961533),
                                (2018,8,19,18,0,0,37.95677158,89.59151267),
                                (2018,8,19,19,0,0,37.76621258,89.59350017),
                                (2018,8,19,20,0,0,37.61102567,89.59560700),
                                (2018,8,19,21,0,0,37.48082142,89.59774017),
                                (2018,8,19,22,0,0,37.35529325,89.59979083),
                                (2018,8,19,23,0,0,37.20012145,89.60174091),
                                (2018,8,20,0,0,0,37.05665858,89.60336492),
                                (2018,8,20,1,0,0,36.85874633,89.60490033),
                                (2018,8,20,2,0,0,36.54961125,89.60641542),
                                (2018,8,20,3,0,0,36.19804325,89.60792867),
                                (2018,8,20,4,0,0,35.78512958,89.60987975),
                                (2018,8,20,5,0,0,35.39923483,89.61179358),
                                (2018,8,20,6,0,0,35.06631925,89.61374467),
                                (2018,8,20,7,0,0,34.77131642,89.61548150),
                                (2018,8,20,8,0,0,34.49620900,89.61693408),
                                (2018,8,20,9,0,0,34.22517558,89.61815042),
                                (2018,8,20,10,0,0,33.94901417,89.61911833),
                                (2018,8,20,11,0,0,33.64355392,89.61982250),
                                (2018,8,20,12,0,0,33.27227942,89.62048892),
                                (2018,8,20,13,0,0,32.90013817,89.62096983),
                                (2018,8,20,14,0,0,32.46349300,89.62151350),
                                (2018,8,20,15,0,0,32.02376708,89.62192600),
                                (2018,8,20,16,0,0,31.59548308,89.62225083),
                                (2018,8,20,17,0,0,31.19124208,89.62246442),
                                (2018,8,20,18,0,0,30.81481433,89.62247408),
                                (2018,8,20,19,0,0,30.45782692,89.62217617),
                                (2018,8,20,20,0,0,30.10282467,89.62152942),
                                (2018,8,20,21,0,0,29.72432783,89.62061350),
                                (2018,8,20,22,0,0,29.30178533,89.61929825),
                                (2018,8,20,23,0,0,28.85083973,89.61771300),
                                (2018,8,21,0,0,0,28.37055592,89.61596733),
                                (2018,8,21,1,0,0,27.79768275,89.61387975),
                                (2018,8,21,2,0,0,27.16353083,89.61190408),
                                (2018,8,21,3,0,0,26.49394983,89.61007283),
                                (2018,8,21,4,0,0,25.80354492,89.60827642),
                                (2018,8,21,5,0,0,25.11822533,89.60651867),
                                (2018,8,21,6,0,0,24.46107125,89.60472225),
                                (2018,8,21,7,0,0,23.83598233,89.60285108),
                                (2018,8,21,8,0,0,23.23244258,89.60091717),
                                (2018,8,21,9,0,0,22.64006208,89.59893267),
                                (2018,8,21,10,0,0,22.05377125,89.59692933),
                                (2018,8,21,11,0,0,21.44792750,89.59491058),
                                (2018,8,21,12,0,0,20.80277233,89.59293817),
                                (2018,8,21,13,0,0,20.10930150,89.59113625),
                                (2018,8,21,14,0,0,19.38365792,89.58962975),
                                (2018,8,21,15,0,0,18.64660600,89.58843217),
                                (2018,8,21,16,0,0,17.91437233,89.58751150),
                                (2018,8,21,17,0,0,17.20506900,89.58674958),
                                (2018,8,21,18,0,0,16.52349600,89.58607250),
                                (2018,8,21,19,0,0,15.84926392,89.58521658),
                                (2018,8,21,20,0,0,15.16010908,89.58393200),
                                (2018,8,21,21,0,0,14.47700767,89.58228700),
                                (2018,8,21,22,0,0,13.78461700,89.58014075),
                                (2018,8,21,23,0,0,13.07040291,89.57743236),
                                (2018,8,22,0,0,0,12.33602467,89.57429650),
                                (2018,8,22,1,0,0,11.59526492,89.57089825),
                                (2018,8,22,2,0,0,10.87025858,89.56731775),
                                (2018,8,22,3,0,0,10.18997275,89.56368008),
                                (2018,8,22,4,0,0,9.58790750,89.56009550),
                                (2018,8,22,5,0,0,9.06258142,89.55658683),
                                (2018,8,22,6,0,0,8.61984633,89.55332325),
                                (2018,8,22,7,0,0,8.25603733,89.55018350),
                                (2018,8,22,8,0,0,7.95489408,89.54704025),
                                (2018,8,22,9,0,0,7.70144908,89.54396217),
                                (2018,8,22,10,0,0,7.48269150,89.54109925),
                                (2018,8,22,11,0,0,7.27177008,89.53863783),
                                (2018,8,22,12,0,0,7.04659783,89.53648967),
                                (2018,8,22,13,0,0,6.82797983,89.53472650),
                                (2018,8,22,14,0,0,6.60002842,89.53345283),
                                (2018,8,22,15,0,0,6.36986133,89.53281900),
                                (2018,8,22,16,0,0,6.14417300,89.53266842),
                                (2018,8,22,17,0,0,5.94334842,89.53279967),
                                (2018,8,22,18,0,0,5.77904542,89.53317325),
                                (2018,8,22,19,0,0,5.64054217,89.53344325),
                                (2018,8,22,20,0,0,5.53450183,89.53373575),
                                (2018,8,22,21,0,0,5.48634342,89.53403758),
                                (2018,8,22,22,0,0,5.45941242,89.53417892),
                                (2018,8,22,23,0,0,5.41365236,89.53415900),
                                (2018,8,23,0,0,0,5.33145017,89.53411358),
                                (2018,8,23,1,0,0,5.20837442,89.53420875),
                                (2018,8,23,2,0,0,5.07409942,89.53438050),
                                (2018,8,23,3,0,0,4.95368625,89.53472675),
                                (2018,8,23,4,0,0,4.85880558,89.53531358),
                                (2018,8,23,5,0,0,4.79526500,89.53590433),
                                (2018,8,23,6,0,0,4.77833142,89.53640267),
                                (2018,8,23,7,0,0,4.82615792,89.53668783),
                                (2018,8,23,8,0,0,4.91350383,89.53665175),
                                (2018,8,23,9,0,0,5.03904083,89.53629633),
                                (2018,8,23,10,0,0,5.21000433,89.53562467),
                                (2018,8,23,11,0,0,5.41966975,89.53482367),
                                (2018,8,23,12,0,0,5.64592425,89.53376700),
                                (2018,8,23,13,0,0,5.86502600,89.53260808),
                                (2018,8,23,14,0,0,6.11054967,89.53162575),
                                (2018,8,23,15,0,0,6.38558867,89.53089142),
                                (2018,8,23,16,0,0,6.67172342,89.53019542),
                                (2018,8,23,17,0,0,6.91808975,89.52949667),
                                (2018,8,23,18,0,0,7.15364333,89.52895333),
                                (2018,8,23,19,0,0,7.43611317,89.52847408),
                                (2018,8,23,20,0,0,7.79010558,89.52816908),
                                (2018,8,23,21,0,0,8.21071133,89.52776967),
                                (2018,8,23,22,0,0,8.69093850,89.52738850),
                                (2018,8,23,23,0,0,9.20293909,89.52675445),
                                (2018,8,24,0,0,0,9.68409650,89.52561983),
                                (2018,8,24,1,0,0,10.11124958,89.52417092),
                                (2018,8,24,2,0,0,10.49778067,89.52288600),
                                (2018,8,24,3,0,0,10.85411267,89.52202508),
                                (2018,8,24,4,0,0,11.22886150,89.52169900),
                                (2018,8,24,5,0,0,11.64665225,89.52172133),
                                (2018,8,24,6,0,0,12.08885617,89.52179367),
                                (2018,8,24,7,0,0,12.55883842,89.52189042),
                                (2018,8,24,8,0,0,13.07039500,89.52172550),
                                (2018,8,24,9,0,0,13.58075500,89.52113392),
                                (2018,8,24,10,0,0,14.06705808,89.52031950),
                                (2018,8,24,11,0,0,14.52868608,89.51932883),
                                (2018,8,24,12,0,0,14.95755358,89.51841733),
                                (2018,8,24,13,0,0,15.34865025,89.51792667),
                                (2018,8,24,14,0,0,15.71442550,89.51788858),
                                (2018,8,24,15,0,0,16.06778775,89.51825825),
                                (2018,8,24,16,0,0,16.42413617,89.51893975),
                                (2018,8,24,17,0,0,16.79749092,89.51982467),
                                (2018,8,24,18,0,0,17.19519875,89.52083075),
                                (2018,8,24,19,0,0,17.61961458,89.52176892),
                                (2018,8,24,20,0,0,18.04755775,89.52258575),
                                (2018,8,24,21,0,0,18.46690692,89.52332358),
                                (2018,8,24,22,0,0,18.85965133,89.52399150),
                                (2018,8,24,23,0,0,19.22448145,89.52469200),
                                (2018,8,25,0,0,0,19.55169600,89.52547267),
                                (2018,8,25,1,0,0,19.85305792,89.52672500),
                                (2018,8,25,2,0,0,20.13029992,89.52844083),
                                (2018,8,25,3,0,0,20.38326250,89.53055983),
                                (2018,8,25,4,0,0,20.63777533,89.53310850),
                                (2018,8,25,5,0,0,20.89730617,89.53570100),
                                (2018,8,25,6,0,0,21.13385425,89.53810067),
                                (2018,8,25,7,0,0,21.34969617,89.54059475),
                                (2018,8,25,8,0,0,21.57682592,89.54320900),
                                (2018,8,25,9,0,0,21.83516508,89.54570208),
                                (2018,8,25,10,0,0,22.08172300,89.54814500),
                                (2018,8,25,11,0,0,22.27498900,89.55077283),
                                (2018,8,25,12,0,0,22.41338450,89.55367825),
                                (2018,8,25,13,0,0,22.51082642,89.55705675),
                                (2018,8,25,14,0,0,22.59017000,89.56098092),
                                (2018,8,25,15,0,0,22.67651500,89.56550183),
                                (2018,8,25,16,0,0,22.78190358,89.57040433),
                                (2018,8,25,17,0,0,22.87790800,89.57528667),
                                (2018,8,25,18,0,0,22.98064742,89.58010533),
                                (2018,8,25,19,0,0,23.20516483,89.58444500),
                                (2018,8,25,20,0,0,23.55800625,89.58812558),
                                (2018,8,25,21,0,0,23.92967008,89.59104692),
                                (2018,8,25,22,0,0,24.28106183,89.59338400),
                                (2018,8,25,23,0,0,24.56756255,89.59543082),
                                (2018,8,26,0,0,0,24.79229542,89.59754783),
                                (2018,8,26,1,0,0,25.00097833,89.59970050),
                                (2018,8,26,2,0,0,25.15661583,89.60204333),
                                (2018,8,26,3,0,0,25.28027167,89.60472308),
                                (2018,8,26,4,0,0,25.38289142,89.60772233),
                                (2018,8,26,5,0,0,25.53472750,89.61101833),
                                (2018,8,26,6,0,0,25.78256158,89.61444042),
                                (2018,8,26,7,0,0,26.08126675,89.61708425),
                                (2018,8,26,8,0,0,26.39102258,89.61872000),
                                (2018,8,26,9,0,0,26.66727375,89.61959267),
                                (2018,8,26,10,0,0,26.91498675,89.62004625),
                                (2018,8,26,11,0,0,27.07508917,89.62007942),
                                (2018,8,26,12,0,0,27.12189442,89.61998275),
                                (2018,8,26,13,0,0,27.03667433,89.62032150),
                                (2018,8,26,14,0,0,26.85809575,89.62120767),
                                (2018,8,26,15,0,0,26.65637625,89.62278225),
                                (2018,8,26,16,0,0,26.52744342,89.62493333),
                                (2018,8,26,17,0,0,26.50979125,89.62738658),
                                (2018,8,26,18,0,0,26.50575692,89.62968933),
                                (2018,8,26,19,0,0,26.50740017,89.63147300),
                                (2018,8,26,20,0,0,26.51449183,89.63254050),
                                (2018,8,26,21,0,0,26.49162017,89.63293575),
                                (2018,8,26,22,0,0,26.40195242,89.63281000),
                                (2018,8,26,23,0,0,26.21999264,89.63242427),
                                (2018,8,27,0,0,0,25.93737208,89.63217350),
                                (2018,8,27,1,0,0,25.59750833,89.63221967),
                                (2018,8,27,2,0,0,25.25089292,89.63272825),
                                (2018,8,27,3,0,0,24.93228450,89.63385142),
                                (2018,8,27,4,0,0,24.66744683,89.63534800),
                                (2018,8,27,5,0,0,24.47887108,89.63686633),
                                (2018,8,27,6,0,0,24.35886417,89.63806392),
                                (2018,8,27,7,0,0,24.28702783,89.63871933),
                                (2018,8,27,8,0,0,24.23965275,89.63870408),
                                (2018,8,27,9,0,0,24.17860258,89.63795308),
                                (2018,8,27,10,0,0,24.05819258,89.63670725),
                                (2018,8,27,11,0,0,23.87506217,89.63515817),
                                (2018,8,27,12,0,0,23.64807925,89.63355075),
                                (2018,8,27,13,0,0,23.40849275,89.63209767),
                                (2018,8,27,14,0,0,23.19948408,89.63091750),
                                (2018,8,27,15,0,0,23.06291342,89.62994250),
                                (2018,8,27,16,0,0,23.01486475,89.62905842),
                                (2018,8,27,17,0,0,23.06232417,89.62823508),
                                (2018,8,27,18,0,0,23.20890558,89.62736250),
                                (2018,8,27,19,0,0,23.43098225,89.62614483),
                                (2018,8,27,20,0,0,23.69172100,89.62454650),
                                (2018,8,27,21,0,0,23.95857575,89.62267783),
                                (2018,8,27,22,0,0,24.18206375,89.62072450),
                                (2018,8,27,23,0,0,24.34866945,89.61886191),
                                (2018,8,28,0,0,0,24.45577917,89.61693142),
                                (2018,8,28,1,0,0,24.56742933,89.61492883),
                                (2018,8,28,2,0,0,24.75945408,89.61285892),
                                (2018,8,28,3,0,0,25.02427542,89.61117775),
                                (2018,8,28,4,0,0,25.37699258,89.60997650),
                                (2018,8,28,5,0,0,25.80173983,89.60900908),
                                (2018,8,28,6,0,0,26.29502183,89.60800383),
                                (2018,8,28,7,0,0,26.85106842,89.60691767),
                                (2018,8,28,8,0,0,27.43871433,89.60565942),
                                (2018,8,28,9,0,0,28.04004808,89.60418517),
                                (2018,8,28,10,0,0,28.64202317,89.60234850),
                                (2018,8,28,11,0,0,29.25596250,89.60018242),
                                (2018,8,28,12,0,0,29.84311500,89.59810742),
                                (2018,8,28,13,0,0,30.38842233,89.59648967),
                                (2018,8,28,14,0,0,30.99158017,89.59510550),
                                (2018,8,28,15,0,0,31.62807350,89.59405725),
                                (2018,8,28,16,0,0,32.29741358,89.59315758),
                                (2018,8,28,17,0,0,33.01772025,89.59216967),
                                (2018,8,28,18,0,0,33.79272125,89.59089400),
                                (2018,8,28,19,0,0,34.63735050,89.58931000),
                                (2018,8,28,20,0,0,35.50672917,89.58727308),
                                (2018,8,28,21,0,0,36.38030567,89.58490283),
                                (2018,8,28,22,0,0,37.25792583,89.58262325),
                                (2018,8,28,23,0,0,38.19446182,89.58035564),
                                (2018,8,29,0,0,0,39.13025575,89.57833658),
                                (2018,8,29,1,0,0,40.07927517,89.57712558),
                                (2018,8,29,2,0,0,41.10075700,89.57682733),
                                (2018,8,29,3,0,0,42.22723758,89.57737125),
                                (2018,8,29,4,0,0,43.42628367,89.57816308),
                                (2018,8,29,5,0,0,44.69456317,89.57873167),
                                (2018,8,29,6,0,0,46.01890767,89.57891425),
                                (2018,8,29,7,0,0,47.35229683,89.57839150),
                                (2018,8,29,8,0,0,48.64576233,89.57727000),
                                (2018,8,29,9,0,0,49.84520950,89.57574417),
                                (2018,8,29,10,0,0,50.91583608,89.57395200),
                                (2018,8,29,11,0,0,51.86206267,89.57237508),
                                (2018,8,29,12,0,0,52.69348408,89.57102192),
                                (2018,8,29,13,0,0,53.43671733,89.56986600),
                                (2018,8,29,14,0,0,54.10577700,89.56898550),
                                (2018,8,29,15,0,0,54.73967742,89.56841900),
                                (2018,8,29,16,0,0,55.36831192,89.56784250),
                                (2018,8,29,17,0,0,56.01775333,89.56663292),
                                (2018,8,29,18,0,0,56.69014850,89.56457342),
                                (2018,8,29,19,0,0,57.34290983,89.56163150),
                                (2018,8,29,20,0,0,57.92037867,89.55823433),
                                (2018,8,29,21,0,0,58.40055558,89.55405733),
                                (2018,8,29,22,0,0,58.80447642,89.54947958),
                                (2018,8,29,23,0,0,59.18391636,89.54515191),
                                (2018,8,30,0,0,0,59.56863975,89.54146117),
                                (2018,8,30,1,0,0,59.98726400,89.53862117),
                                (2018,8,30,2,0,0,60.44338917,89.53550792),
                                (2018,8,30,3,0,0,60.94202250,89.53240700),
                                (2018,8,30,4,0,0,61.52510908,89.53019550),
                                (2018,8,30,5,0,0,62.30141558,89.52882450),
                                (2018,8,30,6,0,0,63.23234517,89.52655258),
                                (2018,8,30,7,0,0,64.18551908,89.52277242),
                                (2018,8,30,8,0,0,65.05221542,89.51798150),
                                (2018,8,30,9,0,0,65.78874567,89.51288608),
                                (2018,8,30,10,0,0,66.39739992,89.50762850),
                                (2018,8,30,11,0,0,66.88249992,89.50236100),
                                (2018,8,30,12,0,0,67.26876533,89.49778908),
                                (2018,8,30,13,0,0,67.61181367,89.49413742),
                                (2018,8,30,14,0,0,68.00312475,89.49137667),
                                (2018,8,30,15,0,0,68.47523950,89.48965425),
                                (2018,8,30,16,0,0,69.09054200,89.48868333),
                                (2018,8,30,17,0,0,69.78034875,89.48759100),
                                (2018,8,30,18,0,0,70.49653642,89.48603975),
                                (2018,8,30,19,0,0,71.17398850,89.48373890),
                                (2018,8,30,20,0,0,71.76632933,89.48073358),
                                (2018,8,30,21,0,0,72.25229608,89.47757383),
                                (2018,8,30,22,0,0,72.56062867,89.47454167),
                                (2018,8,30,23,0,0,72.72030891,89.47205418),
                                (2018,8,31,0,0,0,72.78367033,89.47058617),
                                (2018,8,31,1,0,0,72.79584608,89.47001058),
                                (2018,8,31,2,0,0,72.82121708,89.47024675),
                                (2018,8,31,3,0,0,72.91582725,89.47120033),
                                (2018,8,31,4,0,0,73.08838033,89.47251725),
                                (2018,8,31,5,0,0,73.28873742,89.47370592),
                                (2018,8,31,6,0,0,73.47989375,89.47439775),
                                (2018,8,31,7,0,0,73.64833642,89.47456658),
                                (2018,8,31,8,0,0,73.75160925,89.47434108),
                                (2018,8,31,9,0,0,73.74895075,89.47410950),
                                (2018,8,31,10,0,0,73.46312400,89.47311025),
                                (2018,8,31,11,0,0,73.25443725,89.47343692),
                                (2018,8,31,12,0,0,72.91568050,89.47448392),
                                (2018,8,31,13,0,0,72.51390917,89.47625742),
                                (2018,8,31,14,0,0,72.10946583,89.47843700),
                                (2018,8,31,15,0,0,71.70633308,89.48036592),
                                (2018,8,31,16,0,0,71.31075692,89.48184075),
                                (2018,8,31,17,0,0,70.94840642,89.48271517),
                                (2018,8,31,18,0,0,70.60546450,89.48266983),
                                (2018,8,31,19,0,0,70.26638683,89.48139183),
                                (2018,8,31,20,0,0,69.85886425,89.47904800),
                                (2018,8,31,21,0,0,69.35091525,89.47582858),
                                (2018,8,31,22,0,0,68.76125050,89.47225950),
                                (2018,8,31,23,0,0,68.08549355,89.46847100),
                                (2018,9,1,0,0,0,67.36985375,89.46497483),
                                (2018,9,1,1,0,0,66.66926025,89.46184200),
                                (2018,9,1,2,0,0,66.04349025,89.45890600),
                                (2018,9,1,3,0,0,65.45510617,89.45566600),
                                (2018,9,1,4,0,0,64.94390542,89.45219325),
                                (2018,9,1,5,0,0,64.53820458,89.44775292),
                                (2018,9,1,6,0,0,64.19832733,89.44217008),
                                (2018,9,1,7,0,0,63.84546308,89.43526533),
                                (2018,9,1,8,0,0,63.43328592,89.42726650),
                                (2018,9,1,9,0,0,62.95974167,89.41883333),
                                (2018,9,1,10,0,0,62.39545525,89.41045150),
                                (2018,9,1,11,0,0,61.82841617,89.40343550),
                                (2018,9,1,12,0,0,61.25954192,89.39650150),
                                (2018,9,1,13,0,0,60.71858442,89.38993083),
                                (2018,9,1,14,0,0,60.26779925,89.38402908),
                                (2018,9,1,15,0,0,59.96107758,89.37870342),
                                (2018,9,1,16,0,0,59.81344858,89.37342250),
                                (2018,9,1,17,0,0,59.80404575,89.36821083),
                                (2018,9,1,18,0,0,59.90012558,89.36329883),
                                (2018,9,1,19,0,0,60.03973933,89.35883492),
                                (2018,9,1,20,0,0,60.22098375,89.35446150),
                                (2018,9,1,21,0,0,60.32153933,89.34928800),
                                (2018,9,1,22,0,0,60.28506717,89.34322950),
                                (2018,9,1,23,0,0,60.10992091,89.33673300),
                                (2018,9,2,0,0,0,59.90082633,89.32977525),
                                (2018,9,2,1,0,0,59.67275742,89.32252817),
                                (2018,9,2,2,0,0,59.46022475,89.31666983),
                                (2018,9,2,3,0,0,59.33139067,89.31070800),
                                (2018,9,2,4,0,0,59.25677750,89.30457200),
                                (2018,9,2,5,0,0,59.25429242,89.29836267),
                                (2018,9,2,6,0,0,59.29609350,89.29171308),
                                (2018,9,2,7,0,0,59.36232017,89.28459008),
                                (2018,9,2,8,0,0,59.35307992,89.27640233),
                                (2018,9,2,9,0,0,59.27982442,89.26807142),
                                (2018,9,2,10,0,0,59.13225058,89.25920433),
                                (2018,9,2,11,0,0,58.89982817,89.25032200),
                                (2018,9,2,12,0,0,58.61111308,89.24218308),
                                (2018,9,2,13,0,0,58.32182942,89.23513817),
                                (2018,9,2,14,0,0,58.06479658,89.22819333),
                                (2018,9,2,15,0,0,57.86383450,89.22213892),
                                (2018,9,2,16,0,0,57.72874000,89.21633325),
                                (2018,9,2,17,0,0,57.66217992,89.21011258),
                                (2018,9,2,18,0,0,57.68110408,89.20344558),
                                (2018,9,2,19,0,0,57.73901742,89.19590350),
                                (2018,9,2,20,0,0,57.78148025,89.18756758),
                                (2018,9,2,21,0,0,57.77930683,89.17875742),
                                (2018,9,2,22,0,0,57.70186292,89.16948950),
                                (2018,9,2,23,0,0,57.55896964,89.16059800),
                                (2018,9,3,0,0,0,57.35535117,89.15217733),
                                (2018,9,3,1,0,0,57.10111833,89.14434833),
                                (2018,9,3,2,0,0,56.80622900,89.13720350),
                                (2018,9,3,3,0,0,56.48860708,89.13066125),
                                (2018,9,3,4,0,0,56.17970617,89.12448525),
                                (2018,9,3,5,0,0,55.89517275,89.11813300),
                                (2018,9,3,6,0,0,55.64265117,89.11176275),
                                (2018,9,3,7,0,0,55.41771025,89.10543217),
                                (2018,9,3,8,0,0,55.21996392,89.09930267),
                                (2018,9,3,9,0,0,55.03626542,89.09334333),
                                (2018,9,3,10,0,0,54.84071192,89.08747058),
                                (2018,9,3,11,0,0,54.61203458,89.08185925),
                                (2018,9,3,12,0,0,54.34138142,89.07693325),
                                (2018,9,3,13,0,0,54.02968142,89.07280375),
                                (2018,9,3,14,0,0,53.69848450,89.06935883),
                                (2018,9,3,15,0,0,53.37403792,89.06661575),
                                (2018,9,3,16,0,0,53.06817267,89.06453242),
                                (2018,9,3,17,0,0,52.78116325,89.06296958),
                                (2018,9,3,18,0,0,52.54127550,89.06191342),
                                (2018,9,3,19,0,0,52.36125325,89.06106008),
                                (2018,9,3,20,0,0,52.19394192,89.06020225),
                                (2018,9,3,21,0,0,52.04604550,89.05895808),
                                (2018,9,3,22,0,0,51.90090158,89.05693900),
                                (2018,9,3,23,0,0,51.74503609,89.05445527),
                                (2018,9,4,0,0,0,51.56424933,89.05130025),
                                (2018,9,4,1,0,0,51.37462008,89.04807333),
                                (2018,9,4,2,0,0,51.17930067,89.04456933),
                                (2018,9,4,3,0,0,50.97322092,89.04079392),
                                (2018,9,4,4,0,0,50.75275867,89.03724650),
                                (2018,9,4,5,0,0,50.53433708,89.03387842),
                                (2018,9,4,6,0,0,50.33541083,89.03055367),
                                (2018,9,4,7,0,0,50.17201925,89.02711792),
                                (2018,9,4,8,0,0,50.04061758,89.02338967),
                                (2018,9,4,9,0,0,49.92361933,89.01930233),
                                (2018,9,4,10,0,0,49.79701817,89.01461575),
                                (2018,9,4,11,0,0,49.63957725,89.00955033),
                                (2018,9,4,12,0,0,49.46029175,89.00454642),
                                (2018,9,4,13,0,0,49.27217450,88.99974650),
                                (2018,9,4,14,0,0,49.08580967,88.99542750),
                                (2018,9,4,15,0,0,48.90574375,88.99154400),
                                (2018,9,4,16,0,0,48.73659783,88.98810583),
                                (2018,9,4,17,0,0,48.58739083,88.98514283),
                                (2018,9,4,18,0,0,48.46919842,88.98211817),
                                (2018,9,4,19,0,0,48.36747558,88.97886908),
                                (2018,9,4,20,0,0,48.28559708,88.97529050),
                                (2018,9,4,21,0,0,48.21699758,88.97154633),
                                (2018,9,4,22,0,0,48.15104267,88.96768000),
                                (2018,9,4,23,0,0,48.06333309,88.96390173),
                                (2018,9,5,0,0,0,47.94622642,88.96056600),
                                (2018,9,5,1,0,0,47.80822092,88.95792967),
                                (2018,9,5,2,0,0,47.66772958,88.95603000),
                                (2018,9,5,3,0,0,47.54213883,88.95493450),
                                (2018,9,5,4,0,0,47.45257100,88.95457083),
                                (2018,9,5,5,0,0,47.40943217,88.95473550),
                                (2018,9,5,6,0,0,47.40055475,88.95494000),
                                (2018,9,5,7,0,0,47.42483392,88.95480425),
                                (2018,9,5,8,0,0,47.46592775,88.95399450),
                                (2018,9,5,9,0,0,47.50139017,88.95235942),
                                (2018,9,5,10,0,0,47.51495875,88.95010158),
                                (2018,9,5,11,0,0,47.50002717,88.94756125),
                                (2018,9,5,12,0,0,47.45349317,88.94514575),
                                (2018,9,5,13,0,0,47.38185608,88.94314908),
                                (2018,9,5,14,0,0,47.30426350,88.94173950),
                                (2018,9,5,15,0,0,47.25313100,88.94088383),
                                (2018,9,5,16,0,0,47.23176092,88.94043533),
                                (2018,9,5,17,0,0,47.24906467,88.94022925),
                                (2018,9,5,18,0,0,47.30298550,88.93988517),
                                (2018,9,5,19,0,0,47.37166175,88.93922017),
                                (2018,9,5,20,0,0,47.44768658,88.93812125),
                                (2018,9,5,21,0,0,47.52437608,88.93661650),
                                (2018,9,5,22,0,0,47.59182425,88.93476733),
                                (2018,9,5,23,0,0,47.63260809,88.93279436),
                                (2018,9,6,0,0,0,47.64621250,88.93100367),
                                (2018,9,6,1,0,0,47.62378958,88.92957575),
                                (2018,9,6,2,0,0,47.58229442,88.92859450),
                                (2018,9,6,3,0,0,47.54151050,88.92816508),
                                (2018,9,6,4,0,0,47.51374358,88.92810433),
                                (2018,9,6,5,0,0,47.50247617,88.92828658),
                                (2018,9,6,6,0,0,47.51029608,88.92844108),
                                (2018,9,6,7,0,0,47.53445825,88.92834783),
                                (2018,9,6,8,0,0,47.56662133,88.92775550),
                                (2018,9,6,9,0,0,47.59498892,88.92659908),
                                (2018,9,6,10,0,0,47.60425450,88.92498925),
                                (2018,9,6,11,0,0,47.58301250,88.92325917),
                                (2018,9,6,12,0,0,47.52757225,88.92154758),
                                (2018,9,6,13,0,0,47.44146175,88.91986042),
                                (2018,9,6,14,0,0,47.33313117,88.91860200),
                                (2018,9,6,15,0,0,47.20770925,88.91774017),
                                (2018,9,6,16,0,0,47.06123217,88.91696250),
                                (2018,9,6,17,0,0,46.89216525,88.91611642),
                                (2018,9,6,18,0,0,46.70788658,88.91475333),
                                (2018,9,6,19,0,0,46.53624517,88.91273967),
                                (2018,9,6,20,0,0,46.40778767,88.90979342),
                                (2018,9,6,21,0,0,46.31885958,88.90656892),
                                (2018,9,6,22,0,0,46.27087575,88.90386442),
                                (2018,9,6,23,0,0,46.27484718,88.90065664),
                                (2018,9,7,0,0,0,46.31779075,88.89637583),
                                (2018,9,7,1,0,0,46.35793625,88.89163950),
                                (2018,9,7,2,0,0,46.36192800,88.88666300),
                                (2018,9,7,3,0,0,46.32706617,88.88196975),
                                (2018,9,7,4,0,0,46.26090108,88.87732200),
                                (2018,9,7,5,0,0,46.17423683,88.87275142),
                                (2018,9,7,6,0,0,46.08405650,88.86824975),
                                (2018,9,7,7,0,0,45.99725375,88.86370083),
                                (2018,9,7,8,0,0,45.92329542,88.85905992),
                                (2018,9,7,9,0,0,45.86281133,88.85413175),
                                (2018,9,7,10,0,0,45.80347258,88.84866800),
                                (2018,9,7,11,0,0,45.74718508,88.84275825),
                                (2018,9,7,12,0,0,45.69477883,88.83649350),
                                (2018,9,7,13,0,0,45.64026558,88.82982092),
                                (2018,9,7,14,0,0,45.57931825,88.82309450),
                                (2018,9,7,15,0,0,45.51461008,88.81655783),
                                (2018,9,7,16,0,0,45.44583142,88.81021375),
                                (2018,9,7,17,0,0,45.37388558,88.80405150),
                                (2018,9,7,18,0,0,45.30201967,88.79820800),
                                (2018,9,7,19,0,0,45.25217367,88.79259975),
                                (2018,9,7,20,0,0,45.23308858,88.78703150),
                                (2018,9,7,21,0,0,45.23974717,88.78145583),
                                (2018,9,7,22,0,0,45.27017225,88.77568367),
                                (2018,9,7,23,0,0,45.31854618,88.76960564),
                                (2018,9,8,0,0,0,45.37300092,88.76358242),
                                (2018,9,8,1,0,0,45.42489433,88.75767475),
                                (2018,9,8,2,0,0,45.47738958,88.75179142),
                                (2018,9,8,3,0,0,45.52332892,88.74608142),
                                (2018,9,8,4,0,0,45.57088700,88.74073650),
                                (2018,9,8,5,0,0,45.62433500,88.73580983),
                                (2018,9,8,6,0,0,45.68772400,88.73129700),
                                (2018,9,8,7,0,0,45.75538717,88.72702850),
                                (2018,9,8,8,0,0,45.82994725,88.72285958),
                                (2018,9,8,9,0,0,45.91545717,88.71867433),
                                (2018,9,8,10,0,0,46.00807850,88.71443200),
                                (2018,9,8,11,0,0,46.09756575,88.71011800),
                                (2018,9,8,12,0,0,46.17445783,88.70584808),
                                (2018,9,8,13,0,0,46.23181642,88.70190250),
                                (2018,9,8,14,0,0,46.27508317,88.69825433),
                                (2018,9,8,15,0,0,46.29546583,88.69501050),
                                (2018,9,8,16,0,0,46.30106675,88.69229058),
                                (2018,9,8,17,0,0,46.30210400,88.68999383),
                                (2018,9,8,18,0,0,46.30176175,88.68806550),
                                (2018,9,8,19,0,0,46.31263750,88.68631592),
                                (2018,9,8,20,0,0,46.33774117,88.68481642),
                                (2018,9,8,21,0,0,46.37655500,88.68336258),
                                (2018,9,8,22,0,0,46.42454600,88.68184258),
                                (2018,9,8,23,0,0,46.47430000,88.68024909),
                                (2018,9,9,0,0,0,46.51865167,88.67862233),
                                (2018,9,9,1,0,0,46.54787000,88.67694883),
                                (2018,9,9,2,0,0,46.55622858,88.67518658),
                                (2018,9,9,3,0,0,46.54938117,88.67367933),
                                (2018,9,9,4,0,0,46.53473200,88.67260708),
                                (2018,9,9,5,0,0,46.51922275,88.67188992),
                                (2018,9,9,6,0,0,46.50806692,88.67136467),
                                (2018,9,9,7,0,0,46.50444517,88.67094167),
                                (2018,9,9,8,0,0,46.51038300,88.67044608),
                                (2018,9,9,9,0,0,46.52793142,88.66983475),
                                (2018,9,9,10,0,0,46.55302017,88.66902092),
                                (2018,9,9,11,0,0,46.58174058,88.66803542),
                                (2018,9,9,12,0,0,46.60341683,88.66687433),
                                (2018,9,9,13,0,0,46.64387075,88.66716742),
                                (2018,9,9,14,0,0,46.63535542,88.66590117),
                                (2018,9,9,15,0,0,46.61347900,88.66487533),
                                (2018,9,9,16,0,0,46.58297783,88.66418942),
                                (2018,9,9,17,0,0,46.55117575,88.66382208),
                                (2018,9,9,18,0,0,46.52557592,88.66368392),
                                (2018,9,9,19,0,0,46.50946275,88.66366792),
                                (2018,9,9,20,0,0,46.50302300,88.66369000),
                                (2018,9,9,21,0,0,46.50696575,88.66360717),
                                (2018,9,9,22,0,0,46.51690358,88.66333100),
                                (2018,9,9,23,0,0,46.52485327,88.66270664),
                                (2018,9,10,0,0,0,46.52219908,88.66183633),
                                (2018,9,10,1,0,0,46.50602350,88.66083867),
                                (2018,9,10,2,0,0,46.47619283,88.65988700),
                                (2018,9,10,3,0,0,46.43420800,88.65921692),
                                (2018,9,10,4,0,0,46.38215400,88.65894092),
                                (2018,9,10,5,0,0,46.32541892,88.65904183),
                                (2018,9,10,6,0,0,46.27034367,88.65942633),
                                (2018,9,10,7,0,0,46.22323375,88.65997633),
                                (2018,9,10,8,0,0,46.18756142,88.66049500),
                                (2018,9,10,9,0,0,46.16340408,88.66072958),
                                (2018,9,10,10,0,0,46.14582067,88.66063675),
                                (2018,9,10,11,0,0,46.12850158,88.66010758),
                                (2018,9,10,12,0,0,46.10768408,88.65912275),
                                (2018,9,10,13,0,0,46.07772825,88.65788308),
                                (2018,9,10,14,0,0,46.03679867,88.65665400),
                                (2018,9,10,15,0,0,45.98540608,88.65567925),
                                (2018,9,10,16,0,0,45.92971808,88.65509025),
                                (2018,9,10,17,0,0,45.87550558,88.65497225),
                                (2018,9,10,18,0,0,45.82690258,88.65519367),
                                (2018,9,10,19,0,0,45.78724058,88.65554925),
                                (2018,9,10,20,0,0,45.76025025,88.65585608),
                                (2018,9,10,21,0,0,45.74156967,88.65578908),
                                (2018,9,10,22,0,0,45.72539550,88.65516133),
                                (2018,9,10,23,0,0,45.70442573,88.65412555),
                                (2018,9,11,0,0,0,45.67996475,88.65283975),
                                (2018,9,11,1,0,0,45.64814367,88.65142900),
                                (2018,9,11,2,0,0,45.60635083,88.65002700),
                                (2018,9,11,3,0,0,45.55199958,88.64877025),
                                (2018,9,11,4,0,0,45.48889067,88.64777683),
                                (2018,9,11,5,0,0,45.42360167,88.64700842),
                                (2018,9,11,6,0,0,45.34865650,88.64647858),
                                (2018,9,11,7,0,0,45.27852667,88.64614700),
                                (2018,9,11,8,0,0,45.21459475,88.64571333),
                                (2018,9,11,9,0,0,45.15802783,88.64494442),
                                (2018,9,11,10,0,0,45.10500542,88.64377600),
                                (2018,9,11,11,0,0,45.05492025,88.64193858),
                                (2018,9,11,12,0,0,45.00786817,88.63945500),
                                (2018,9,11,13,0,0,44.95057342,88.63648400),
                                (2018,9,11,14,0,0,44.87846825,88.63318783),
                                (2018,9,11,15,0,0,44.78864425,88.62971733),
                                (2018,9,11,16,0,0,44.68538875,88.62651200),
                                (2018,9,11,17,0,0,44.57712300,88.62368350),
                                (2018,9,11,18,0,0,44.47387183,88.62106725),
                                (2018,9,11,19,0,0,44.38401208,88.61829917),
                                (2018,9,11,20,0,0,44.30699800,88.61492817),
                                (2018,9,11,21,0,0,44.22162567,88.61035433),
                                (2018,9,11,22,0,0,44.11202925,88.60411117),
                                (2018,9,11,23,0,0,43.99662227,88.59725300),
                                (2018,9,12,0,0,0,43.88490375,88.59026658),
                                (2018,9,12,1,0,0,43.77307200,88.58303300),
                                (2018,9,12,2,0,0,43.66816850,88.57584900),
                                (2018,9,12,3,0,0,43.56703308,88.56893942),
                                (2018,9,12,4,0,0,43.46534833,88.56216208),
                                (2018,9,12,5,0,0,43.36030125,88.55519467),
                                (2018,9,12,6,0,0,43.25638517,88.54784700),
                                (2018,9,12,7,0,0,43.15161567,88.54016000),
                                (2018,9,12,8,0,0,43.04707142,88.53185367),
                                (2018,9,12,9,0,0,42.93351542,88.52312183),
                                (2018,9,12,10,0,0,42.81077742,88.51402758),
                                (2018,9,12,11,0,0,42.68168508,88.50482108),
                                (2018,9,12,12,0,0,42.54501175,88.49565892),
                                (2018,9,12,13,0,0,42.39912308,88.48672908),
                                (2018,9,12,14,0,0,42.24440058,88.47825867),
                                (2018,9,12,15,0,0,42.08468092,88.47052392),
                                (2018,9,12,16,0,0,41.91919025,88.46365283),
                                (2018,9,12,17,0,0,41.75358342,88.45787625),
                                (2018,9,12,18,0,0,41.58796300,88.45343783),
                                (2018,9,12,19,0,0,41.41460858,88.45075583),
                                (2018,9,12,20,0,0,41.23344100,88.45024475),
                                (2018,9,12,21,0,0,41.05350425,88.45177900),
                                (2018,9,12,22,0,0,40.87569483,88.45478550),
                                (2018,9,12,23,0,0,40.70978200,88.45866591),
                                (2018,9,13,0,0,0,40.54191158,88.46289975),
                                (2018,9,13,1,0,0,40.39701042,88.46751667),
                                (2018,9,13,2,0,0,40.25194350,88.47204058),
                                (2018,9,13,3,0,0,40.11259933,88.47626375),
                                (2018,9,13,4,0,0,39.99647908,88.47979933),
                                (2018,9,13,5,0,0,39.87336883,88.48323467),
                                (2018,9,13,6,0,0,39.75344533,88.48624283),
                                (2018,9,13,7,0,0,39.59757708,88.48779133),
                                (2018,9,13,8,0,0,39.42602108,88.48937967),
                                (2018,9,13,9,0,0,39.27936050,88.49116808),
                                (2018,9,13,10,0,0,39.15240883,88.49288400),
                                (2018,9,13,11,0,0,39.03644225,88.49427742),
                                (2018,9,13,12,0,0,38.92481842,88.49548358),
                                (2018,9,13,13,0,0,38.82614467,88.49647358),
                                (2018,9,13,14,0,0,38.74167800,88.49699533),
                                (2018,9,13,15,0,0,38.67853100,88.49716942),
                                (2018,9,13,16,0,0,38.63501692,88.49673525),
                                (2018,9,13,17,0,0,38.60201367,88.49569808),
                                (2018,9,13,18,0,0,38.53612425,88.49365092),
                                (2018,9,13,19,0,0,38.45752750,88.49109083),
                                (2018,9,13,20,0,0,38.37844917,88.48843767),
                                (2018,9,13,21,0,0,38.31771033,88.48586617),
                                (2018,9,13,22,0,0,38.28993375,88.48342767),
                                (2018,9,13,23,0,0,38.28822873,88.48124000),
                                (2018,9,14,0,0,0,38.30055025,88.47931475),
                                (2018,9,14,1,0,0,38.32213192,88.47778850),
                                (2018,9,14,2,0,0,38.35260433,88.47675733),
                                (2018,9,14,3,0,0,38.38045017,88.47601650),
                                (2018,9,14,4,0,0,38.39703525,88.47547908),
                                (2018,9,14,5,0,0,38.39717633,88.47530017),
                                (2018,9,14,6,0,0,38.37972358,88.47580008),
                                (2018,9,14,7,0,0,38.32956575,88.47714525),
                                (2018,9,14,8,0,0,38.27324258,88.47918358),
                                (2018,9,14,9,0,0,38.21803817,88.48159575),
                                (2018,9,14,10,0,0,38.17779092,88.48402442),
                                (2018,9,14,11,0,0,38.14299833,88.48635125),
                                (2018,9,14,12,0,0,38.10685733,88.48868892),
                                (2018,9,14,13,0,0,38.06681867,88.49054658),
                                (2018,9,14,14,0,0,38.00054675,88.49117200),
                                (2018,9,14,15,0,0,37.89083550,88.49069308),
                                (2018,9,14,16,0,0,37.73139267,88.48991392),
                                (2018,9,14,17,0,0,37.53153300,88.48939342),
                                (2018,9,14,18,0,0,37.30715750,88.48938117),
                                (2018,9,14,19,0,0,37.05250750,88.48954617),
                                (2018,9,14,20,0,0,36.76503400,88.49013400),
                                (2018,9,14,21,0,0,37.64768517,88.47591958),
                                (2018,9,14,22,0,0,37.89956517,88.42742933),
                                (2018,9,14,23,0,0,36.25712455,88.39110482),
                                (2018,9,15,0,0,0,35.21444558,88.34026958),
                                (2018,9,15,1,0,0,33.82663250,88.28827708),
                                (2018,9,15,2,0,0,32.77521367,88.24245867),
                                (2018,9,15,3,0,0,31.25251883,88.19285192),
                                (2018,9,15,4,0,0,30.10216767,88.14120358),
                                (2018,9,15,5,0,0,28.09601367,88.10112258),
                                (2018,9,15,6,0,0,25.72999308,88.06317150),
                                (2018,9,15,7,0,0,24.19173983,87.99598908),
                                (2018,9,15,8,0,0,22.99033833,87.95635058),
                                (2018,9,15,9,0,0,22.07691467,87.90933958),
                                (2018,9,15,10,0,0,20.97519250,87.87701225),
                                (2018,9,15,11,0,0,20.59265808,87.82673300),
                                (2018,9,15,12,0,0,19.84320733,87.77344033),
                                (2018,9,15,13,0,0,18.97445750,87.72794083),
                                (2018,9,15,14,0,0,18.37768492,87.67012408),
                                (2018,9,15,15,0,0,18.58123200,87.60402117),
                                (2018,9,15,16,0,0,17.71389975,87.54728767),
                                (2018,9,15,17,0,0,17.92834608,87.48359000),
                                (2018,9,15,18,0,0,17.65651275,87.45728917),
                                (2018,9,15,19,0,0,15.86953133,87.39824058),
                                (2018,9,15,20,0,0,13.94592300,87.36485650),
                                (2018,9,15,21,0,0,14.04767800,87.29643292),
                                (2018,9,15,22,0,0,15.12110942,87.22514525),
                                (2018,9,15,23,0,0,14.72548618,87.15100200),
                                (2018,9,16,0,0,0,14.06370842,87.06791025),
                                (2018,9,16,1,0,0,14.63096325,87.01130375),
                                (2018,9,16,2,0,0,14.54654800,86.93688417),
                                (2018,9,16,3,0,0,14.30131000,86.85260433),
                                (2018,9,16,4,0,0,14.34179983,86.78558850),
                                (2018,9,16,5,0,0,14.65236075,86.72426025),
                                (2018,9,16,6,0,0,14.22311575,86.66901883),
                                (2018,9,16,7,0,0,13.68281108,86.60376642),
                                (2018,9,16,8,0,0,12.95725625,86.54165433),
                                (2018,9,16,9,0,0,13.48065142,86.48139600),
                                (2018,9,16,10,0,0,13.45662250,86.41208792),
                                (2018,9,16,11,0,0,13.65391825,86.38865742),
                                (2018,9,16,12,0,0,13.55907650,86.39512333),
                                (2018,9,16,13,0,0,13.34151925,86.48587225),
                                (2018,9,16,14,0,0,12.77231075,86.54742108),
                                (2018,9,16,15,0,0,13.40225892,86.44874142),
                                (2018,9,16,16,0,0,13.29763933,86.36968508),
                                (2018,9,16,17,0,0,13.68402908,86.31053850),
                                (2018,9,16,18,0,0,14.21817583,86.24961950),
                                (2018,9,16,19,0,0,14.98760942,86.18853750),
                                (2018,9,16,20,0,0,15.58364192,86.14684400),
                                (2018,9,16,21,0,0,16.09206700,86.08284692),
                                (2018,9,16,22,0,0,16.67505550,86.02371158),
                                (2018,9,16,23,0,0,16.99226027,85.97371873),
                                (2018,9,17,0,0,0,17.44567708,85.90881750),
                                (2018,9,17,1,0,0,17.54056300,85.84596008),
                                (2018,9,17,2,0,0,17.97041367,85.78487267),
                                (2018,9,17,3,0,0,18.17265600,85.71573258),
                                (2018,9,17,4,0,0,18.33217633,85.67656942),
                                (2018,9,17,5,0,0,18.47804958,85.63993433),
                                (2018,9,17,6,0,0,18.92484517,85.58113133),
                                (2018,9,17,7,0,0,19.34510267,85.51701867),
                                (2018,9,17,8,0,0,19.57692250,85.46035142),
                                (2018,9,17,9,0,0,19.56232675,85.41462067),
                                (2018,9,17,10,0,0,19.86813225,85.38312050),
                                (2018,9,17,11,0,0,20.20385617,85.35738400),
                                (2018,9,17,12,0,0,20.54948925,85.29307642),
                                (2018,9,17,13,0,0,20.18283675,85.23648392),
                                (2018,9,17,14,0,0,20.28472383,85.16798633),
                                (2018,9,17,15,0,0,20.47624983,85.10178558),
                                (2018,9,17,16,0,0,20.72245383,85.02727517),
                                (2018,9,17,17,0,0,20.79173358,84.95241242),
                                (2018,9,17,18,0,0,20.96773000,84.85738475),
                                (2018,9,17,19,0,0,20.83554858,84.76236783),
                                (2018,9,17,20,0,0,20.99003000,84.69393450),
                                (2018,9,17,21,0,0,21.02993550,84.62884675),
                                (2018,9,17,22,0,0,21.36776250,84.58571092),
                                (2018,9,17,23,0,0,21.65769918,84.53746945),
                                (2018,9,18,0,0,0,21.70931533,84.46357100),
                                (2018,9,18,1,0,0,21.68860750,84.39819333),
                                (2018,9,18,2,0,0,22.19895050,84.30696967),
                                (2018,9,18,3,0,0,22.48460975,84.23364700),
                                (2018,9,18,4,0,0,22.55992925,84.16742417),
                                (2018,9,18,5,0,0,22.27737608,84.08175283),
                                (2018,9,18,6,0,0,22.27454900,83.97277008),
                                (2018,9,18,7,0,0,22.43657883,83.86957400),
                                (2018,9,18,8,0,0,22.50591875,83.79274158),
                                (2018,9,18,9,0,0,22.61266300,83.72781617),
                                (2018,9,18,10,0,0,22.36857692,83.63608967),
                                (2018,9,18,11,0,0,22.02084275,83.54226825),
                                (2018,9,18,12,0,0,21.86185950,83.44837217),
                                (2018,9,18,13,0,0,21.94876917,83.35014067),
                                (2018,9,18,14,0,0,21.85333650,83.25708558),
                                (2018,9,18,15,0,0,21.87386700,83.17000950),
                                (2018,9,18,16,0,0,21.86240542,83.07412583),
                                (2018,9,18,17,0,0,21.79011317,82.96527333),
                                (2018,9,18,18,0,0,21.74017217,82.85765483),
                                (2018,9,18,19,0,0,21.49864217,82.74996275),
                                (2018,9,18,20,0,0,21.24286808,82.66492392),
                                (2018,9,18,21,0,0,21.00412017,82.55770792),
                                (2018,9,18,22,0,0,21.08102033,82.42365642),
                                (2018,9,18,23,0,0,21.11526800,82.35141555),
                                (2018,9,19,0,0,0,21.06764150,82.34766967),
                                (2018,9,19,1,0,0,21.00736267,82.34493100),
                                (2018,9,19,2,0,0,20.94404358,82.34265825),
                                (2018,9,19,3,0,0,20.88090367,82.34109208),
                                (2018,9,19,4,0,0,20.82274725,82.34101475),
                                (2018,9,19,5,0,0,20.77245742,82.34100117),
                                (2018,9,19,6,0,0,20.72632425,82.34111175),
                                (2018,9,19,7,0,0,20.68928483,82.34106200),
                                (2018,9,19,8,0,0,20.65949617,82.33977292),
                                (2018,9,19,9,0,0,20.62563400,82.33768492),
                                (2018,9,19,10,0,0,20.58487325,82.33459508),
                                (2018,9,19,11,0,0,20.53699617,82.33113642),
                                (2018,9,19,12,0,0,20.48386417,82.32791450),
                                (2018,9,19,13,0,0,20.43121908,82.32548550),
                                (2018,9,19,14,0,0,20.38454550,82.32419958),
                                (2018,9,19,15,0,0,20.34648408,82.32421992),
                                (2018,9,19,16,0,0,20.31925558,82.32491767),
                                (2018,9,19,17,0,0,20.31347442,82.32561017),
                                (2018,9,19,18,0,0,20.29645033,82.32441533),
                                (2018,9,19,19,0,0,20.27567267,82.31938925),
                                (2018,9,19,20,0,0,20.25137208,82.31426067),
                                (2018,9,19,21,0,0,20.21616750,82.30902483),
                                (2018,9,19,22,0,0,20.17236442,82.30455925),
                                (2018,9,19,23,0,0,20.12448927,82.30094764),
                                (2018,9,20,0,0,0,20.05979575,82.29743775),
                                (2018,9,20,1,0,0,19.97549517,82.29414592),
                                (2018,9,20,2,0,0,19.90521667,82.29542442),
                                (2018,9,20,3,0,0,19.85686800,82.29832917),
                                (2018,9,20,4,0,0,19.82724175,82.30024942),
                                (2018,9,20,5,0,0,19.78275375,82.29488592),
                                (2018,9,20,6,0,0,18.93705942,82.17650983),
                                (2018,9,20,7,0,0,17.89983142,82.03127675),
                                (2018,9,20,8,0,0,16.80514500,81.89424500),
                                (2018,9,20,9,0,0,15.73119625,81.76218700),
                                (2018,9,20,10,0,0,14.73151325,81.62720767),
                                (2018,9,20,11,0,0,13.77090933,81.49742250),
                                (2018,9,20,12,0,0,12.92618442,81.34982242),
                                (2018,9,20,13,0,0,12.33593433,81.17743667),
                                (2018,9,20,14,0,0,11.78102392,81.00563992),
                                (2018,9,20,15,0,0,11.22344583,80.83544750),
                                (2018,9,20,16,0,0,10.69826458,80.66401850),
                                (2018,9,20,17,0,0,10.21701433,80.49185908),
                                (2018,9,20,18,0,0,9.80946908,80.31591508),
                                (2018,9,20,19,0,0,9.39742125,80.13271158),
                                (2018,9,20,20,0,0,9.06237925,79.94331983),
                                (2018,9,20,21,0,0,9.06534350,79.75095742),
                                (2018,9,20,22,0,0,9.06776333,79.56269983),
                                (2018,9,20,23,0,0,9.06994882,79.37668836),
                                (2018,9,21,0,0,0,9.07257917,79.18759933),
                                (2018,9,21,1,0,0,9.07512075,78.99846025),
                                (2018,9,21,2,0,0,9.07759892,78.80912883),
                                (2018,9,21,3,0,0,9.39447842,78.63337400),
                                (2018,9,21,4,0,0,9.80467208,78.47005658),
                                (2018,9,21,5,0,0,10.20681183,78.30762158),
                                (2018,9,21,6,0,0,10.62274633,78.13715742),
                                (2018,9,21,7,0,0,11.33780875,78.03060875),
                                (2018,9,21,8,0,0,12.17350942,77.97923817),
                                (2018,9,21,9,0,0,12.91424392,78.04685242),
                                (2018,9,21,10,0,0,13.64417117,78.13245833),
                                (2018,9,21,11,0,0,14.46431567,78.20276592),
                                (2018,9,21,12,0,0,15.27790475,78.26849575),
                                (2018,9,21,13,0,0,15.62705708,78.23376083),
                                (2018,9,21,14,0,0,15.62297742,78.23346633),
                                (2018,9,21,15,0,0,15.62283625,78.23352950)],
                                dtype=dtypes)
    return ship_coords_array

def find_ship_at_time(target_time):
    '''
    Returns a [lon, lat] coordinate for the Oden at the time supplied.
    target_time should be a dt.datetime object
    '''
    ship_coords = get_ao2018_track()

    for i in np.arange(len(ship_coords)-1):
        ship_time = dt.datetime(ship_coords['year'][i],ship_coords['month'][i],ship_coords['day'][i],
                                ship_coords['hours'][i],ship_coords['mins'][i],ship_coords['secs'][i])
        next_ship_time = dt.datetime(ship_coords['year'][i+1], ship_coords['month'][i+1],
                                     ship_coords['day'][i+1], ship_coords['hours'][i+1],
                                     ship_coords['mins'][i+1], ship_coords['secs'][i+1])
        if target_time == ship_time:
            return i
        elif target_time == next_ship_time:
            # NB covers case where target time is equal to the last timestep
            return i+1
        elif target_time > ship_time and target_time < next_ship_time:
            # if the target time is later than this iteration's ship time
            # and earlier than the subsequent time
            # i.e. it is between those two timesteps,
            # so work out which one it's closest to in time
            time_since_first_step = target_time - ship_time
            time_until_next_step = next_ship_time - target_time
            if time_since_first_step < time_until_next_step:
                return i
            else:
                return i+1
    # if this point is reached then there is no match - probably time supplied outside campaign
    print("No ship coordinates from this time")
    return None

def take_drift_timesteps_from_cube(cube):
    '''
    Function takes an iris cube and returns only the cube timesteps
    within AO2018 drift period. Also returns the indices
    of the cube corresponding to these timesteps
    '''
    drift_begin = dt.datetime(year=2018,month=8,day=2)
    drift_end = dt.datetime(year=2018,month=9,day=19)

    drift_time_inds = []
    cube_datestamps = cube.coord('time').units.num2date(cube.coord('time').points)
    for t,datestamp in enumerate(cube_datestamps):
        if datestamp >= drift_begin and datestamp <= drift_end:
            drift_time_inds.append(t)

    if drift_time_inds == []:
        # cube timesteps don't cover drift period
        print("[take_drift_timesteps_from_cube] no drift times found, returning original cube")
        return [cube, drift_time_inds]
    else:
        return [cube[drift_time_inds], drift_time_inds]

def colocate_with_ao2018_drift(cube, model_resolution):
    '''
    Function takes iris cube of whatever time and space
    and restricts to location of AO2018 ship for each timestep during drift
    '''
    ship_coords = get_ao2018_track()

    if take_drift_timesteps_from_cube(cube)[1] == []:
        # cube doesn't contain data from drift time
        print("[colocate_with_ao2018_drift] can't colocate, no data from drift period")
        return []

    cube = take_drift_timesteps_from_cube(cube)[0]
    timestamps = cube.coord('time').units.num2date(cube.coord('time').points)
    timestamps = [dt.datetime(T.year,T.month,T.day,T.hour,T.minute,T.second) for T in timestamps]
    n_drift_time = len(timestamps)

    print("[colocate_with_ao2018] constraining data to ship location")
    colocated_cubes = iris.cube.CubeList([])
    for t in np.arange(n_drift_time):
        T = timestamps[t]
        ship_coord_ind = find_ship_at_time(T)
        if ship_coord_ind == None:
            print("ERROR: can't find ship at {}".format(timestamps[t]))
            colocated_cubes.append(None)
        else:
            ship_lon = ship_coords['lon'][ship_coord_ind]
            ship_lat = ship_coords['lat'][ship_coord_ind]
            lon_constraint1 = iris.Constraint(longitude=lambda cell: cell > ship_lon-(0.5*model_resolution[0]))
            lon_constraint2 = iris.Constraint(longitude=lambda cell: cell < ship_lon+(0.5*model_resolution[0]))
            lat_constraint1 = iris.Constraint(latitude =lambda cell: cell > ship_lat-(0.5*model_resolution[1]))
            lat_constraint2 = iris.Constraint(latitude =lambda cell: cell < ship_lat+(0.5*model_resolution[1]))
            colocated_cube = cube[t].extract(lon_constraint1 & lon_constraint2 & lat_constraint1 & lat_constraint2)
            colocated_cubes.append(colocated_cube)

    return colocated_cubes

def ao2018_melt_freeze_times(freeze_onset, times):
    # for an array of datetimes
    # return indices before and after
    # the date of freeze_onset
    melt_times = []
    freeze_times = []
    for t,timestep in enumerate(times):
        if timestep < freeze_onset:
            melt_times.append(t)
        else:
            freeze_times.append(t)
    return melt_times, freeze_times